/*
 * Contributor(s): Natasha Noy noy@smi.stanford.edu
 */
package org.bioontology.bioportal.metadata;


import java.util.*;

import edu.stanford.smi.protegex.owl.model.*;

public class Constants {

	public static OWLModel bioportalMetadataOntology = null;
	public static OWLClass virtualOntologyClass = null;
	public static OWLClass omvOntologyClass = null;
	public static RDFProperty virtualURIProperty = null;
	public static RDFProperty currentVersionProperty = null;
	public static ArrayList<RDFProperty> coreProperties = null;
	public static ArrayList<RDFProperty> summaryProperties = null;
	public static RDFProperty versionsProperty = null;
	public static RDFProperty viewsProperty = null;
	public static RDFProperty annotatesByVirtualIdProperty = null;
	public static RDFProperty annotatesProperty = null;
	public static RDFProperty associatedAnnotationsProperty = null;
	public static OWLClass reviewClass = null;
	public static OWLClass evaluationDimensionClass = null;
	public static RDFProperty numericRatingProperty = null;
	public static RDFProperty textualReviewProperty = null;
	public static ArrayList<RDFProperty> reviewDimensions = null;

	public static void initialize (OWLModel model) {
		bioportalMetadataOntology = model; // the metadata ontology
		
 		virtualOntologyClass = bioportalMetadataOntology.getOWLNamedClass(Names.VIRTUAL_ONTOLOGY_CLASS); // the class "Virtual Ontology"
 		omvOntologyClass = bioportalMetadataOntology.getOWLNamedClass(Names.OMV_ONTOLOGY_CLASS); // the class "Virtual Ontology"
		virtualURIProperty = bioportalMetadataOntology.getRDFProperty(Names.VIRTUAL_URI_PROPERTY); // the property "virtualURI" at the "Virtual Ontology" class
		currentVersionProperty = bioportalMetadataOntology.getRDFProperty(Names.CURRENT_VERSION_PROPERTY); //the property pointing to the current version of the virtual ontology
		
		annotatesByVirtualIdProperty = bioportalMetadataOntology.getRDFProperty(Names.ANNOTATES_BY_VIRTUAL_ID_PROPERTY); // property that links an annotations to the virtual id of an ontology ora conccept that it annotates
		annotatesProperty = bioportalMetadataOntology.getRDFProperty(Names.ANNOTATES_PROPERTY); // property that links an annotations to the object that it annotates
		associatedAnnotationsProperty = bioportalMetadataOntology.getRDFProperty(Names.ASSOCIATED_ANNOTATIONS_PROPERTY); // property that links from an ontology or a concept object to the list of corresponding annotations
		
		reviewClass = bioportalMetadataOntology.getOWLNamedClass(Names.REVIEW_CLASS); // instances of this class represent reviews on ontologies
		evaluationDimensionClass = bioportalMetadataOntology.getOWLNamedClass(Names.EVALUATION_DIMENSION_CLASS); // instances of this auxiliary class represent 

		numericRatingProperty = bioportalMetadataOntology.getRDFProperty(Names.NUMERIC_RATING_PROPERTY); // property in Evaluation Dimension class that contains the numeric rating
		textualReviewProperty = bioportalMetadataOntology.getRDFProperty(Names.TEXTUAL_REVIEW_PROPERTY); // property in Evaluation Dimension class that contains the numeric rating
		
		
		coreProperties = new ArrayList<RDFProperty> ();
		for (int i = Names.CORE_PROPERTY_NAMES.length - 1; i >= 0; i--) {
			String nextName = Names.CORE_PROPERTY_NAMES [i];
			RDFProperty nextProperty = bioportalMetadataOntology.getRDFProperty(nextName);
			coreProperties.add (nextProperty);
		}
		
		
		summaryProperties = new ArrayList<RDFProperty> ();
		for (int i = Names.SUMMARY_PROPERTY_NAMES.length - 1; i >= 0; i--) {
			String nextName = Names.SUMMARY_PROPERTY_NAMES [i];
			RDFProperty nextProperty = bioportalMetadataOntology.getRDFProperty(nextName);
			summaryProperties.add (nextProperty);
		}
		
		versionsProperty = bioportalMetadataOntology.getRDFProperty(Names.HAS_VERSIONS_PROPERTY);
		viewsProperty = bioportalMetadataOntology.getRDFProperty(Names.HAS_VIEWS_PROPERTY);

		reviewDimensions = new ArrayList<RDFProperty> ();
		for (int i = Names.REVIEW_DIMENSIONS.length - 1; i >= 0; i--) {
			String nextName = Names.REVIEW_DIMENSIONS [i];
			RDFProperty nextProperty = bioportalMetadataOntology.getRDFProperty(nextName);
			reviewDimensions.add (nextProperty);
		}
		

	}
	
}
