/*
 * Contributor(s): Natasha Noy noy@smi.stanford.edu
 */
package org.bioontology.bioportal.metadata;

import java.io.*;
import java.net.*;
import java.util.*;

import edu.stanford.smi.protege.exception.*;
import edu.stanford.smi.protege.util.*;
import edu.stanford.smi.protegex.owl.*;
import edu.stanford.smi.protegex.owl.model.*;

public class Test {

	/**
	 * @param args
	 * @throws OntologyLoadException 
	 */
	public static void main(String[] args) throws OntologyLoadException {
		String sourceFileName = args[0];
		
		BufferedReader reader;
		try {
			reader = new BufferedReader(new FileReader(sourceFileName));
		} catch (FileNotFoundException e) {
			Log.getLogger().warning ("Exception: " + e);
			return;
		}
		
		OWLModel model;
		try {
			model = ProtegeOWL.createJenaOWLModelFromReader(reader);
		} catch (Exception e) {
			Log.getLogger().warning ("Exception: " + e);
			return;			
		}
		
		testOntologyMetadata (model);
		
	}

	private static void testOntologyMetadata(OWLModel model) {
		Constants.initialize(model);
		
		try {
			OWLIndividual version1 = testCreateNewInstance ();
			OWLIndividual version2 = testCreateNextVersion (version1);

			testMarginalNotesAndReviews (model, version2);
		} catch (URISyntaxException e) {
			Log.getLogger().warning("Exception: " + e);
		}
		
	}

	private static OWLIndividual testCreateNextVersion(OWLIndividual version1) throws URISyntaxException {
		URI virtualURI = new URI ("http://virtualURI.com");
		URI currentURI = new URI ("http://currentURInew.com");
		Collection<PropertyValue> pairs = new ArrayList<PropertyValue> ();

		PropertyValue pair = new PropertyValue ();
		pair.property = "OMV:name";
		pair.value = "test";
		pairs.add(pair);
		
		pair.property = "OMV:hasPriorVersion";
		pair.value = version1;
		pairs.add(pair);
		
		OWLIndividual newIndividual = OntologyMetadata.createNewVersion(virtualURI, currentURI, pairs);
		return newIndividual;

	}

	private static OWLIndividual testCreateNewInstance() throws URISyntaxException {
		URI virtualURI = new URI ("http://virtualURI.com");
		URI currentURI = new URI ("http://currentURI.com");
		Collection<PropertyValue> pairs = new ArrayList<PropertyValue> ();
		
		PropertyValue pair = new PropertyValue ();
		pair.property = "OMV:name";
		pair.value = "test";
		pairs.add(pair);
		
		OWLIndividual newIndividual = OntologyMetadata.createNewVersion(virtualURI, currentURI, pairs);
		return newIndividual;
	}
	
	
	private static void testMarginalNotesAndReviews(OWLModel model, OWLIndividual currentVersion) {
		Collection<EvaluationDimensionData> reviewElements = new ArrayList<EvaluationDimensionData> ();
		EvaluationDimensionData reviewElement;
		
		reviewElement = new EvaluationDimensionData ();
		reviewElement.dimension = model.getRDFProperty(Names.QUALITY_OF_CONTENT_REVIEW);
		reviewElement.rating = new Integer (4);
		reviewElement.text = "Quite nice";
		reviewElements.add(reviewElement);
		
		reviewElement = new EvaluationDimensionData ();
		reviewElement.dimension = model.getRDFProperty(Names.USABILITY_REVIEW);
		reviewElement.rating = new Integer (2);
		reviewElements.add(reviewElement);
		
		reviewElement = new EvaluationDimensionData ();
		reviewElement.dimension = model.getRDFProperty(Names.CORRECTNESS_REVIEW);
		reviewElement.text = "rubbish, really....";
		reviewElements.add(reviewElement);
		
		MarginalNotesAndReviews.createReview (currentVersion, null, reviewElements);
		
		Collection<OWLIndividual> reviewData = MarginalNotesAndReviews.getReviewsForVersion(currentVersion);
		OWLIndividual review = (OWLIndividual) CollectionUtilities.getFirstItem(reviewData);
		
		ArrayList<PropertyValue> test = MarginalNotesAndReviews.getReviewData(review);
	}


}
